@@ -5,7 +5,6 @@ import decimal
 import datetime
 import json
 
-from pymysql.util import byte2int
 from pymysql.charset import charset_by_name
 
 from .event import BinLogEvent
@@ -532,7 +531,7 @@ class UpdateRowsEvent(RowsEvent):
 
 
 class TableMapEvent(BinLogEvent):
-    """This evenement describe the structure of a table.
+    """This event describes the structure of a table.
     It's sent before a change happens on a table.
     An end user of the lib should have no usage of this
     """
@@ -556,10 +555,10 @@ class TableMapEvent(BinLogEvent):
         self.flags = struct.unpack('<H', self.packet.read(2))[0]
 
         # Payload
-        self.schema_length = byte2int(self.packet.read(1))
+        self.schema_length = struct.unpack("!B", self.packet.read(1))[0]
         self.schema = self.packet.read(self.schema_length).decode()
         self.packet.advance(1)
-        self.table_length = byte2int(self.packet.read(1))
+        self.table_length = struct.unpack("!B", self.packet.read(1))[0]
         self.table = self.packet.read(self.table_length).decode()
 
         if self.__only_tables is not None and self.table not in self.__only_tables:
@@ -590,7 +589,7 @@ class TableMapEvent(BinLogEvent):
 
         if len(self.column_schemas) != 0:
             # Read columns meta data
-            column_types = list(self.packet.read(self.column_count))
+            column_types = bytearray(self.packet.read(self.column_count))
             self.packet.read_length_coded_binary()
             for i in range(0, len(column_types)):
                 column_type = column_types[i]
@@ -617,7 +616,7 @@ class TableMapEvent(BinLogEvent):
                         'COLUMN_TYPE': 'BLOB',  # we don't know what it is, so let's not do anything with it.
                         'COLUMN_KEY': '',
                     }
-                col = Column(byte2int(column_type), column_schema, from_packet)
+                col = Column(column_type, column_schema, from_packet)
                 self.columns.append(col)
 
         self.table_obj = Table(self.column_schemas, self.table_id, self.schema,
